@@ -249,6 +249,13 @@ def json_file_to_dict(json_file):
     return data
 
 
+# will turn a dictionary to a json file
+def dict_to_json_file(json_file, dictt):
+    import json
+    with open(json_file, 'w') as f:
+        json.dump(dictt, f)
+
+
 def remove_lines_from_file(file_path, lines_arr_to_remove=None, remove_from=None, remove_until=None):
     """
     Will remove lines from a file if the lines contains certain strings
